[![doc](https://img.shields.io/badge/-Documentation-blue)](https://advestis.github.io/adclean)
[![License: GPL v3](https://img.shields.io/badge/License-GPL%20v3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0)

#### Status
[![pytests](https://github.com/Advestis/adclean/actions/workflows/pull-request.yml/badge.svg)](https://github.com/Advestis/adclean/actions/workflows/pull-request.yml)
[![push-pypi](https://github.com/Advestis/adclean/actions/workflows/push-pypi.yml/badge.svg)](https://github.com/Advestis/adclean/actions/workflows/push-pypi.yml)
[![push-doc](https://github.com/Advestis/adclean/actions/workflows/push-doc.yml/badge.svg)](https://github.com/Advestis/adclean/actions/workflows/push-doc.yml)

![maintained](https://img.shields.io/badge/Maintained%3F-yes-green.svg)
[![issues](https://img.shields.io/github/issues/Advestis/adclean.svg)](https://github.com/Advestis/adclean/issues)
[![pr](https://img.shields.io/github/issues-pr/Advestis/adclean.svg)](https://github.com/Advestis/adclean/pulls)


#### Compatibilities
![ubuntu](https://img.shields.io/badge/Ubuntu-supported--tested-success)
![unix](https://img.shields.io/badge/Other%20Unix-supported--untested-yellow)

![python](https://img.shields.io/pypi/pyversions/adclean)


##### Contact
[![linkedin](https://img.shields.io/badge/LinkedIn-Advestis-blue)](https://www.linkedin.com/company/advestis/)
[![website](https://img.shields.io/badge/website-Advestis.com-blue)](https://www.advestis.com/)
[![mail](https://img.shields.io/badge/mail-maintainers-blue)](mailto:pythondev@advestis.com)

# adclean


## Installation

```

```

## Usage

```python

```